# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gateway/batch_job.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='gateway/batch_job.proto',
  package='gateway',
  syntax='proto3',
  serialized_options=b'Z\n./;gateway',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x17gateway/batch_job.proto\x12\x07gateway\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa3\x08\n\x08\x42\x61tchJob\x12\x14\n\x04name\x18\x01 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\x19\n\x0c\x64isplay_name\x18\t \x01(\tB\x03\xe0\x41\x01\x12\x37\n\x0b\x63reate_time\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xe0\x41\x03\xe0\x41\x05\x12\x36\n\nstart_time\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xe0\x41\x03\xe0\x41\x05\x12\x34\n\x08\x65nd_time\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xe0\x41\x03\xe0\x41\x05\x12\x1a\n\ncreated_by\x18\r \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\x1c\n\x0cnode_pool_id\x18\x02 \x01(\tB\x06\xe0\x41\x02\xe0\x41\x05\x12\x1e\n\x0e\x65nvironment_id\x18\x03 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\x1b\n\x0bsnapshot_id\x18\x13 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\x19\n\tnum_ranks\x18\x0b \x01(\x05\x42\x06\xe0\x41\x01\xe0\x41\x05\x12\x38\n\x08\x65nv_vars\x18\x06 \x03(\x0b\x32\x1e.gateway.BatchJob.EnvVarsEntryB\x06\xe0\x41\x01\xe0\x41\x05\x12\x14\n\x04role\x18\x11 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\x32\n\x0fpython_executor\x18\x07 \x01(\x0b\x32\x17.gateway.PythonExecutorH\x00\x12\x36\n\x11notebook_executor\x18\x08 \x01(\x0b\x32\x19.gateway.NotebookExecutorH\x00\x12\x30\n\x0eshell_executor\x18\x10 \x01(\x0b\x32\x16.gateway.ShellExecutorH\x00\x12\x19\n\timage_ref\x18\n \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12?\n\x0b\x61nnotations\x18\x12 \x03(\x0b\x32\".gateway.BatchJob.AnnotationsEntryB\x06\xe0\x41\x01\xe0\x41\x05\x12.\n\x05state\x18\x04 \x01(\x0e\x32\x17.gateway.BatchJob.StateB\x06\xe0\x41\x03\xe0\x41\x05\x12\x16\n\x06status\x18\x05 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\x0e\n\x06shared\x18\x14 \x01(\x08\x1a.\n\x0c\x45nvVarsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9a\x01\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x07\x12\n\n\x06QUEUED\x10\x01\x12\x0b\n\x07PENDING\x10\x02\x12\x0b\n\x07RUNNING\x10\x03\x12\r\n\tCOMPLETED\x10\x04\x12\n\n\x06\x46\x41ILED\x10\x05\x12\x0e\n\nCANCELLING\x10\x08\x12\r\n\tCANCELLED\x10\x06\x12\x0c\n\x08\x44\x45LETING\x10\tB\n\n\x08\x65xecutor\"W\n\x15\x43reateBatchJobRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12)\n\tbatch_job\x18\x02 \x01(\x0b\x32\x11.gateway.BatchJobB\x03\xe0\x41\x02\"\'\n\x12GetBatchJobRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"\x88\x01\n\x14ListBatchJobsRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x16\n\tpage_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01\x12\x17\n\npage_token\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12\x13\n\x06\x66ilter\x18\x04 \x01(\tB\x03\xe0\x41\x01\x12\x15\n\x08order_by\x18\x05 \x01(\tB\x03\xe0\x41\x01\"k\n\x15ListBatchJobsResponse\x12%\n\nbatch_jobs\x18\x01 \x03(\x0b\x32\x11.gateway.BatchJob\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"*\n\x15\x44\x65leteBatchJobRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"F\n\x1b\x42\x61tchDeleteBatchJobsRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x12\n\x05names\x18\x02 \x03(\tB\x03\xe0\x41\x02\"*\n\x15\x43\x61ncelBatchJobRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"\xd3\x01\n\x16GetBatchJobLogsRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\r\n\x05ranks\x18\x03 \x03(\x05\x12\x16\n\tpage_size\x18\x04 \x01(\x05\x42\x03\xe0\x41\x01\x12\x17\n\npage_token\x18\x05 \x01(\tB\x03\xe0\x41\x01\x12\x33\n\nstart_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x01\x12\x13\n\x06\x66ilter\x18\x07 \x01(\tB\x03\xe0\x41\x01\x12\x1c\n\x0fstart_from_head\x18\x08 \x01(\x08\x42\x03\xe0\x41\x01\"V\n\x17GetBatchJobLogsResponse\x12\"\n\x07\x65ntries\x18\x02 \x03(\x0b\x32\x11.gateway.LogEntry\x12\x17\n\x0fnext_page_token\x18\x03 \x01(\t\"\xbb\x01\n\x0ePythonExecutor\x12<\n\x0btarget_type\x18\x01 \x01(\x0e\x32\".gateway.PythonExecutor.TargetTypeB\x03\xe0\x41\x02\x12\x13\n\x06target\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\x11\n\x04\x61rgs\x18\x03 \x03(\tB\x03\xe0\x41\x01\"C\n\nTargetType\x12\x1b\n\x17TARGET_TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06MODULE\x10\x01\x12\x0c\n\x08\x46ILENAME\x10\x02\"%\n\rShellExecutor\x12\x14\n\x07\x63ommand\x18\x01 \x01(\tB\x03\xe0\x41\x02\"2\n\x10NotebookExecutor\x12\x1e\n\x11notebook_filename\x18\x01 \x01(\tB\x03\xe0\x41\x02\"W\n\x08LogEntry\x12,\n\x08log_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04rank\x18\x02 \x01(\x05\x12\x0f\n\x07message\x18\x03 \x01(\tB\x0cZ\n./;gatewayb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])



_BATCHJOB_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='gateway.BatchJob.State',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREATING', index=1, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='QUEUED', index=2, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PENDING', index=3, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUNNING', index=4, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMPLETED', index=5, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=6, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CANCELLING', index=7, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CANCELLED', index=8, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DELETING', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=996,
  serialized_end=1150,
)
_sym_db.RegisterEnumDescriptor(_BATCHJOB_STATE)

_PYTHONEXECUTOR_TARGETTYPE = _descriptor.EnumDescriptor(
  name='TargetType',
  full_name='gateway.PythonExecutor.TargetType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TARGET_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MODULE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FILENAME', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2125,
  serialized_end=2192,
)
_sym_db.RegisterEnumDescriptor(_PYTHONEXECUTOR_TARGETTYPE)


_BATCHJOB_ENVVARSENTRY = _descriptor.Descriptor(
  name='EnvVarsEntry',
  full_name='gateway.BatchJob.EnvVarsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='gateway.BatchJob.EnvVarsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='gateway.BatchJob.EnvVarsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=895,
  serialized_end=941,
)

_BATCHJOB_ANNOTATIONSENTRY = _descriptor.Descriptor(
  name='AnnotationsEntry',
  full_name='gateway.BatchJob.AnnotationsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='gateway.BatchJob.AnnotationsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='gateway.BatchJob.AnnotationsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=943,
  serialized_end=993,
)

_BATCHJOB = _descriptor.Descriptor(
  name='BatchJob',
  full_name='gateway.BatchJob',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.BatchJob.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='display_name', full_name='gateway.BatchJob.display_name', index=1,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='create_time', full_name='gateway.BatchJob.create_time', index=2,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='gateway.BatchJob.start_time', index=3,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='gateway.BatchJob.end_time', index=4,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_by', full_name='gateway.BatchJob.created_by', index=5,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_pool_id', full_name='gateway.BatchJob.node_pool_id', index=6,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='environment_id', full_name='gateway.BatchJob.environment_id', index=7,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='snapshot_id', full_name='gateway.BatchJob.snapshot_id', index=8,
      number=19, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_ranks', full_name='gateway.BatchJob.num_ranks', index=9,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='env_vars', full_name='gateway.BatchJob.env_vars', index=10,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='role', full_name='gateway.BatchJob.role', index=11,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='python_executor', full_name='gateway.BatchJob.python_executor', index=12,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notebook_executor', full_name='gateway.BatchJob.notebook_executor', index=13,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shell_executor', full_name='gateway.BatchJob.shell_executor', index=14,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_ref', full_name='gateway.BatchJob.image_ref', index=15,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='annotations', full_name='gateway.BatchJob.annotations', index=16,
      number=18, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='gateway.BatchJob.state', index=17,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='gateway.BatchJob.status', index=18,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shared', full_name='gateway.BatchJob.shared', index=19,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_BATCHJOB_ENVVARSENTRY, _BATCHJOB_ANNOTATIONSENTRY, ],
  enum_types=[
    _BATCHJOB_STATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='executor', full_name='gateway.BatchJob.executor',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=103,
  serialized_end=1162,
)


_CREATEBATCHJOBREQUEST = _descriptor.Descriptor(
  name='CreateBatchJobRequest',
  full_name='gateway.CreateBatchJobRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='gateway.CreateBatchJobRequest.parent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='batch_job', full_name='gateway.CreateBatchJobRequest.batch_job', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1164,
  serialized_end=1251,
)


_GETBATCHJOBREQUEST = _descriptor.Descriptor(
  name='GetBatchJobRequest',
  full_name='gateway.GetBatchJobRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.GetBatchJobRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1253,
  serialized_end=1292,
)


_LISTBATCHJOBSREQUEST = _descriptor.Descriptor(
  name='ListBatchJobsRequest',
  full_name='gateway.ListBatchJobsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='gateway.ListBatchJobsRequest.parent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='gateway.ListBatchJobsRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='gateway.ListBatchJobsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='gateway.ListBatchJobsRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_by', full_name='gateway.ListBatchJobsRequest.order_by', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1295,
  serialized_end=1431,
)


_LISTBATCHJOBSRESPONSE = _descriptor.Descriptor(
  name='ListBatchJobsResponse',
  full_name='gateway.ListBatchJobsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='batch_jobs', full_name='gateway.ListBatchJobsResponse.batch_jobs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='gateway.ListBatchJobsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_size', full_name='gateway.ListBatchJobsResponse.total_size', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1433,
  serialized_end=1540,
)


_DELETEBATCHJOBREQUEST = _descriptor.Descriptor(
  name='DeleteBatchJobRequest',
  full_name='gateway.DeleteBatchJobRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.DeleteBatchJobRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1542,
  serialized_end=1584,
)


_BATCHDELETEBATCHJOBSREQUEST = _descriptor.Descriptor(
  name='BatchDeleteBatchJobsRequest',
  full_name='gateway.BatchDeleteBatchJobsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='gateway.BatchDeleteBatchJobsRequest.parent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='names', full_name='gateway.BatchDeleteBatchJobsRequest.names', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1586,
  serialized_end=1656,
)


_CANCELBATCHJOBREQUEST = _descriptor.Descriptor(
  name='CancelBatchJobRequest',
  full_name='gateway.CancelBatchJobRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.CancelBatchJobRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1658,
  serialized_end=1700,
)


_GETBATCHJOBLOGSREQUEST = _descriptor.Descriptor(
  name='GetBatchJobLogsRequest',
  full_name='gateway.GetBatchJobLogsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.GetBatchJobLogsRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ranks', full_name='gateway.GetBatchJobLogsRequest.ranks', index=1,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='gateway.GetBatchJobLogsRequest.page_size', index=2,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='gateway.GetBatchJobLogsRequest.page_token', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='gateway.GetBatchJobLogsRequest.start_time', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='gateway.GetBatchJobLogsRequest.filter', index=5,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_from_head', full_name='gateway.GetBatchJobLogsRequest.start_from_head', index=6,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1703,
  serialized_end=1914,
)


_GETBATCHJOBLOGSRESPONSE = _descriptor.Descriptor(
  name='GetBatchJobLogsResponse',
  full_name='gateway.GetBatchJobLogsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='gateway.GetBatchJobLogsResponse.entries', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='gateway.GetBatchJobLogsResponse.next_page_token', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1916,
  serialized_end=2002,
)


_PYTHONEXECUTOR = _descriptor.Descriptor(
  name='PythonExecutor',
  full_name='gateway.PythonExecutor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_type', full_name='gateway.PythonExecutor.target_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target', full_name='gateway.PythonExecutor.target', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='args', full_name='gateway.PythonExecutor.args', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PYTHONEXECUTOR_TARGETTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2005,
  serialized_end=2192,
)


_SHELLEXECUTOR = _descriptor.Descriptor(
  name='ShellExecutor',
  full_name='gateway.ShellExecutor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='command', full_name='gateway.ShellExecutor.command', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2194,
  serialized_end=2231,
)


_NOTEBOOKEXECUTOR = _descriptor.Descriptor(
  name='NotebookExecutor',
  full_name='gateway.NotebookExecutor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='notebook_filename', full_name='gateway.NotebookExecutor.notebook_filename', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2233,
  serialized_end=2283,
)


_LOGENTRY = _descriptor.Descriptor(
  name='LogEntry',
  full_name='gateway.LogEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log_time', full_name='gateway.LogEntry.log_time', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rank', full_name='gateway.LogEntry.rank', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='gateway.LogEntry.message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2285,
  serialized_end=2372,
)

_BATCHJOB_ENVVARSENTRY.containing_type = _BATCHJOB
_BATCHJOB_ANNOTATIONSENTRY.containing_type = _BATCHJOB
_BATCHJOB.fields_by_name['create_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_BATCHJOB.fields_by_name['start_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_BATCHJOB.fields_by_name['end_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_BATCHJOB.fields_by_name['env_vars'].message_type = _BATCHJOB_ENVVARSENTRY
_BATCHJOB.fields_by_name['python_executor'].message_type = _PYTHONEXECUTOR
_BATCHJOB.fields_by_name['notebook_executor'].message_type = _NOTEBOOKEXECUTOR
_BATCHJOB.fields_by_name['shell_executor'].message_type = _SHELLEXECUTOR
_BATCHJOB.fields_by_name['annotations'].message_type = _BATCHJOB_ANNOTATIONSENTRY
_BATCHJOB.fields_by_name['state'].enum_type = _BATCHJOB_STATE
_BATCHJOB_STATE.containing_type = _BATCHJOB
_BATCHJOB.oneofs_by_name['executor'].fields.append(
  _BATCHJOB.fields_by_name['python_executor'])
_BATCHJOB.fields_by_name['python_executor'].containing_oneof = _BATCHJOB.oneofs_by_name['executor']
_BATCHJOB.oneofs_by_name['executor'].fields.append(
  _BATCHJOB.fields_by_name['notebook_executor'])
_BATCHJOB.fields_by_name['notebook_executor'].containing_oneof = _BATCHJOB.oneofs_by_name['executor']
_BATCHJOB.oneofs_by_name['executor'].fields.append(
  _BATCHJOB.fields_by_name['shell_executor'])
_BATCHJOB.fields_by_name['shell_executor'].containing_oneof = _BATCHJOB.oneofs_by_name['executor']
_CREATEBATCHJOBREQUEST.fields_by_name['batch_job'].message_type = _BATCHJOB
_LISTBATCHJOBSRESPONSE.fields_by_name['batch_jobs'].message_type = _BATCHJOB
_GETBATCHJOBLOGSREQUEST.fields_by_name['start_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_GETBATCHJOBLOGSRESPONSE.fields_by_name['entries'].message_type = _LOGENTRY
_PYTHONEXECUTOR.fields_by_name['target_type'].enum_type = _PYTHONEXECUTOR_TARGETTYPE
_PYTHONEXECUTOR_TARGETTYPE.containing_type = _PYTHONEXECUTOR
_LOGENTRY.fields_by_name['log_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['BatchJob'] = _BATCHJOB
DESCRIPTOR.message_types_by_name['CreateBatchJobRequest'] = _CREATEBATCHJOBREQUEST
DESCRIPTOR.message_types_by_name['GetBatchJobRequest'] = _GETBATCHJOBREQUEST
DESCRIPTOR.message_types_by_name['ListBatchJobsRequest'] = _LISTBATCHJOBSREQUEST
DESCRIPTOR.message_types_by_name['ListBatchJobsResponse'] = _LISTBATCHJOBSRESPONSE
DESCRIPTOR.message_types_by_name['DeleteBatchJobRequest'] = _DELETEBATCHJOBREQUEST
DESCRIPTOR.message_types_by_name['BatchDeleteBatchJobsRequest'] = _BATCHDELETEBATCHJOBSREQUEST
DESCRIPTOR.message_types_by_name['CancelBatchJobRequest'] = _CANCELBATCHJOBREQUEST
DESCRIPTOR.message_types_by_name['GetBatchJobLogsRequest'] = _GETBATCHJOBLOGSREQUEST
DESCRIPTOR.message_types_by_name['GetBatchJobLogsResponse'] = _GETBATCHJOBLOGSRESPONSE
DESCRIPTOR.message_types_by_name['PythonExecutor'] = _PYTHONEXECUTOR
DESCRIPTOR.message_types_by_name['ShellExecutor'] = _SHELLEXECUTOR
DESCRIPTOR.message_types_by_name['NotebookExecutor'] = _NOTEBOOKEXECUTOR
DESCRIPTOR.message_types_by_name['LogEntry'] = _LOGENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BatchJob = _reflection.GeneratedProtocolMessageType('BatchJob', (_message.Message,), {

  'EnvVarsEntry' : _reflection.GeneratedProtocolMessageType('EnvVarsEntry', (_message.Message,), {
    'DESCRIPTOR' : _BATCHJOB_ENVVARSENTRY,
    '__module__' : 'gateway.batch_job_pb2'
    # @@protoc_insertion_point(class_scope:gateway.BatchJob.EnvVarsEntry)
    })
  ,

  'AnnotationsEntry' : _reflection.GeneratedProtocolMessageType('AnnotationsEntry', (_message.Message,), {
    'DESCRIPTOR' : _BATCHJOB_ANNOTATIONSENTRY,
    '__module__' : 'gateway.batch_job_pb2'
    # @@protoc_insertion_point(class_scope:gateway.BatchJob.AnnotationsEntry)
    })
  ,
  'DESCRIPTOR' : _BATCHJOB,
  '__module__' : 'gateway.batch_job_pb2'
  # @@protoc_insertion_point(class_scope:gateway.BatchJob)
  })
_sym_db.RegisterMessage(BatchJob)
_sym_db.RegisterMessage(BatchJob.EnvVarsEntry)
_sym_db.RegisterMessage(BatchJob.AnnotationsEntry)

CreateBatchJobRequest = _reflection.GeneratedProtocolMessageType('CreateBatchJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEBATCHJOBREQUEST,
  '__module__' : 'gateway.batch_job_pb2'
  # @@protoc_insertion_point(class_scope:gateway.CreateBatchJobRequest)
  })
_sym_db.RegisterMessage(CreateBatchJobRequest)

GetBatchJobRequest = _reflection.GeneratedProtocolMessageType('GetBatchJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBATCHJOBREQUEST,
  '__module__' : 'gateway.batch_job_pb2'
  # @@protoc_insertion_point(class_scope:gateway.GetBatchJobRequest)
  })
_sym_db.RegisterMessage(GetBatchJobRequest)

ListBatchJobsRequest = _reflection.GeneratedProtocolMessageType('ListBatchJobsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTBATCHJOBSREQUEST,
  '__module__' : 'gateway.batch_job_pb2'
  # @@protoc_insertion_point(class_scope:gateway.ListBatchJobsRequest)
  })
_sym_db.RegisterMessage(ListBatchJobsRequest)

ListBatchJobsResponse = _reflection.GeneratedProtocolMessageType('ListBatchJobsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTBATCHJOBSRESPONSE,
  '__module__' : 'gateway.batch_job_pb2'
  # @@protoc_insertion_point(class_scope:gateway.ListBatchJobsResponse)
  })
_sym_db.RegisterMessage(ListBatchJobsResponse)

DeleteBatchJobRequest = _reflection.GeneratedProtocolMessageType('DeleteBatchJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEBATCHJOBREQUEST,
  '__module__' : 'gateway.batch_job_pb2'
  # @@protoc_insertion_point(class_scope:gateway.DeleteBatchJobRequest)
  })
_sym_db.RegisterMessage(DeleteBatchJobRequest)

BatchDeleteBatchJobsRequest = _reflection.GeneratedProtocolMessageType('BatchDeleteBatchJobsRequest', (_message.Message,), {
  'DESCRIPTOR' : _BATCHDELETEBATCHJOBSREQUEST,
  '__module__' : 'gateway.batch_job_pb2'
  # @@protoc_insertion_point(class_scope:gateway.BatchDeleteBatchJobsRequest)
  })
_sym_db.RegisterMessage(BatchDeleteBatchJobsRequest)

CancelBatchJobRequest = _reflection.GeneratedProtocolMessageType('CancelBatchJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _CANCELBATCHJOBREQUEST,
  '__module__' : 'gateway.batch_job_pb2'
  # @@protoc_insertion_point(class_scope:gateway.CancelBatchJobRequest)
  })
_sym_db.RegisterMessage(CancelBatchJobRequest)

GetBatchJobLogsRequest = _reflection.GeneratedProtocolMessageType('GetBatchJobLogsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBATCHJOBLOGSREQUEST,
  '__module__' : 'gateway.batch_job_pb2'
  # @@protoc_insertion_point(class_scope:gateway.GetBatchJobLogsRequest)
  })
_sym_db.RegisterMessage(GetBatchJobLogsRequest)

GetBatchJobLogsResponse = _reflection.GeneratedProtocolMessageType('GetBatchJobLogsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETBATCHJOBLOGSRESPONSE,
  '__module__' : 'gateway.batch_job_pb2'
  # @@protoc_insertion_point(class_scope:gateway.GetBatchJobLogsResponse)
  })
_sym_db.RegisterMessage(GetBatchJobLogsResponse)

PythonExecutor = _reflection.GeneratedProtocolMessageType('PythonExecutor', (_message.Message,), {
  'DESCRIPTOR' : _PYTHONEXECUTOR,
  '__module__' : 'gateway.batch_job_pb2'
  # @@protoc_insertion_point(class_scope:gateway.PythonExecutor)
  })
_sym_db.RegisterMessage(PythonExecutor)

ShellExecutor = _reflection.GeneratedProtocolMessageType('ShellExecutor', (_message.Message,), {
  'DESCRIPTOR' : _SHELLEXECUTOR,
  '__module__' : 'gateway.batch_job_pb2'
  # @@protoc_insertion_point(class_scope:gateway.ShellExecutor)
  })
_sym_db.RegisterMessage(ShellExecutor)

NotebookExecutor = _reflection.GeneratedProtocolMessageType('NotebookExecutor', (_message.Message,), {
  'DESCRIPTOR' : _NOTEBOOKEXECUTOR,
  '__module__' : 'gateway.batch_job_pb2'
  # @@protoc_insertion_point(class_scope:gateway.NotebookExecutor)
  })
_sym_db.RegisterMessage(NotebookExecutor)

LogEntry = _reflection.GeneratedProtocolMessageType('LogEntry', (_message.Message,), {
  'DESCRIPTOR' : _LOGENTRY,
  '__module__' : 'gateway.batch_job_pb2'
  # @@protoc_insertion_point(class_scope:gateway.LogEntry)
  })
_sym_db.RegisterMessage(LogEntry)


DESCRIPTOR._options = None
_BATCHJOB_ENVVARSENTRY._options = None
_BATCHJOB_ANNOTATIONSENTRY._options = None
_BATCHJOB.fields_by_name['name']._options = None
_BATCHJOB.fields_by_name['display_name']._options = None
_BATCHJOB.fields_by_name['create_time']._options = None
_BATCHJOB.fields_by_name['start_time']._options = None
_BATCHJOB.fields_by_name['end_time']._options = None
_BATCHJOB.fields_by_name['created_by']._options = None
_BATCHJOB.fields_by_name['node_pool_id']._options = None
_BATCHJOB.fields_by_name['environment_id']._options = None
_BATCHJOB.fields_by_name['snapshot_id']._options = None
_BATCHJOB.fields_by_name['num_ranks']._options = None
_BATCHJOB.fields_by_name['env_vars']._options = None
_BATCHJOB.fields_by_name['role']._options = None
_BATCHJOB.fields_by_name['image_ref']._options = None
_BATCHJOB.fields_by_name['annotations']._options = None
_BATCHJOB.fields_by_name['state']._options = None
_BATCHJOB.fields_by_name['status']._options = None
_CREATEBATCHJOBREQUEST.fields_by_name['parent']._options = None
_CREATEBATCHJOBREQUEST.fields_by_name['batch_job']._options = None
_GETBATCHJOBREQUEST.fields_by_name['name']._options = None
_LISTBATCHJOBSREQUEST.fields_by_name['parent']._options = None
_LISTBATCHJOBSREQUEST.fields_by_name['page_size']._options = None
_LISTBATCHJOBSREQUEST.fields_by_name['page_token']._options = None
_LISTBATCHJOBSREQUEST.fields_by_name['filter']._options = None
_LISTBATCHJOBSREQUEST.fields_by_name['order_by']._options = None
_DELETEBATCHJOBREQUEST.fields_by_name['name']._options = None
_BATCHDELETEBATCHJOBSREQUEST.fields_by_name['parent']._options = None
_BATCHDELETEBATCHJOBSREQUEST.fields_by_name['names']._options = None
_CANCELBATCHJOBREQUEST.fields_by_name['name']._options = None
_GETBATCHJOBLOGSREQUEST.fields_by_name['name']._options = None
_GETBATCHJOBLOGSREQUEST.fields_by_name['page_size']._options = None
_GETBATCHJOBLOGSREQUEST.fields_by_name['page_token']._options = None
_GETBATCHJOBLOGSREQUEST.fields_by_name['start_time']._options = None
_GETBATCHJOBLOGSREQUEST.fields_by_name['filter']._options = None
_GETBATCHJOBLOGSREQUEST.fields_by_name['start_from_head']._options = None
_PYTHONEXECUTOR.fields_by_name['target_type']._options = None
_PYTHONEXECUTOR.fields_by_name['target']._options = None
_PYTHONEXECUTOR.fields_by_name['args']._options = None
_SHELLEXECUTOR.fields_by_name['command']._options = None
_NOTEBOOKEXECUTOR.fields_by_name['notebook_filename']._options = None
# @@protoc_insertion_point(module_scope)



from . import options_pb2 as _options_pb2
from . import status_pb2 as _status_pb2
from ..google.api import field_behavior_pb2 as _field_behavior_pb2
from ..google.api import resource_pb2 as _resource_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Snapshot(_message.Message):
    __slots__ = ("name", "create_time", "state", "status", "image_ref", "update_time")
    class State(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        STATE_UNSPECIFIED: _ClassVar[Snapshot.State]
        CREATING: _ClassVar[Snapshot.State]
        READY: _ClassVar[Snapshot.State]
        FAILED: _ClassVar[Snapshot.State]
        DELETING: _ClassVar[Snapshot.State]
    STATE_UNSPECIFIED: Snapshot.State
    CREATING: Snapshot.State
    READY: Snapshot.State
    FAILED: Snapshot.State
    DELETING: Snapshot.State
    NAME_FIELD_NUMBER: _ClassVar[int]
    CREATE_TIME_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    IMAGE_REF_FIELD_NUMBER: _ClassVar[int]
    UPDATE_TIME_FIELD_NUMBER: _ClassVar[int]
    name: str
    create_time: _timestamp_pb2.Timestamp
    state: Snapshot.State
    status: _status_pb2.Status
    image_ref: str
    update_time: _timestamp_pb2.Timestamp
    def __init__(self, name: _Optional[str] = ..., create_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., state: _Optional[_Union[Snapshot.State, str]] = ..., status: _Optional[_Union[_status_pb2.Status, _Mapping]] = ..., image_ref: _Optional[str] = ..., update_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class CreateSnapshotRequest(_message.Message):
    __slots__ = ("parent", "snapshot")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    SNAPSHOT_FIELD_NUMBER: _ClassVar[int]
    parent: str
    snapshot: Snapshot
    def __init__(self, parent: _Optional[str] = ..., snapshot: _Optional[_Union[Snapshot, _Mapping]] = ...) -> None: ...

class GetSnapshotRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class ListSnapshotsRequest(_message.Message):
    __slots__ = ("parent", "page_size", "page_token", "filter", "order_by")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    ORDER_BY_FIELD_NUMBER: _ClassVar[int]
    parent: str
    page_size: int
    page_token: str
    filter: str
    order_by: str
    def __init__(self, parent: _Optional[str] = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ..., filter: _Optional[str] = ..., order_by: _Optional[str] = ...) -> None: ...

class ListSnapshotsResponse(_message.Message):
    __slots__ = ("snapshots", "next_page_token", "total_size")
    SNAPSHOTS_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOTAL_SIZE_FIELD_NUMBER: _ClassVar[int]
    snapshots: _containers.RepeatedCompositeFieldContainer[Snapshot]
    next_page_token: str
    total_size: int
    def __init__(self, snapshots: _Optional[_Iterable[_Union[Snapshot, _Mapping]]] = ..., next_page_token: _Optional[str] = ..., total_size: _Optional[int] = ...) -> None: ...

class DeleteSnapshotRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...



import json
from prance import ResolvingParser

def extract_fields(schema, visited_refs=None):
    if visited_refs is None:
        visited_refs = set()
    if id(schema) in visited_refs:
        return "<circular_reference>"
    visited_refs.add(id(schema))

    if 'allOf' in schema:
        combined = {}
        for subschema in schema['allOf']:
            combined.update(extract_fields(subschema, visited_refs))
        return combined
    elif 'oneOf' in schema or 'anyOf' in schema:
        # For simplicity, take the first option
        key = 'oneOf' if 'oneOf' in schema else 'anyOf'
        return extract_fields(schema[key][0], visited_refs)
    elif 'properties' in schema:
        properties = schema.get('properties', {})
        required = schema.get('required', [])
        fields = {}
        for prop_name, prop_schema in properties.items():
            field_value = extract_fields(prop_schema, visited_refs)
            if prop_name in required:
                fields[prop_name] = field_value
            else:
                fields[prop_name] = field_value  # You can mark optional fields if needed
        return fields
    elif 'type' in schema:
        if schema['type'] == 'array':
            items = extract_fields(schema.get('items', {}), visited_refs)
            return [items]
        elif schema['type'] == 'object':
            return extract_fields(schema.get('properties', {}), visited_refs)
        else:
            if 'default' in schema:
                return schema['default']
            else:
                return "<value>"
    else:
        if 'default' in schema:
            return schema['default']
        else:
            return "<value>"

def construct_json_body(schema):
    return extract_fields(schema)

def generate_curl_commands(spec_string, api_url, default_headers, query_params):
    parser = ResolvingParser(spec_string=spec_string)
    spec = parser.specification
    curl_commands = []

    for path, path_item in spec.get('paths', {}).items():
        for method in ['get', 'post', 'put', 'delete', 'patch', 'options', 'head']:
            if method in path_item:
                details = path_item[method]
                # Skip deprecated endpoints
                if details.get('deprecated', False):
                    continue
                # Handle path parameters
                full_path = path
                path_params = []
                combined_parameters = path_item.get('parameters', []) + details.get('parameters', [])
                for param in combined_parameters:
                    if param['in'] == 'path':
                        param_name = param['name']
                        full_path = full_path.replace('{' + param_name + '}', f'<{param_name}>')
                # Handle query parameters
                for param in combined_parameters:
                    if param['in'] == 'query':
                        param_name = param['name']
                        query_params.append(f'{param_name}=<{param_name}>')
                query_string = '&'.join(query_params)
                if query_string:
                    full_path += f'?{query_string}'
                # Handle security requirements
                headers = default_headers
                security = details.get('security', spec.get('security', []))
                if security:
                    for sec_requirement in security:
                        for sec_name in sec_requirement:
                            sec_scheme = spec['components']['securitySchemes'][sec_name]
                            if sec_scheme['type'] == 'apiKey':
                                sec_scheme_name = sec_scheme["name"]
                                if sec_scheme['in'] == 'header':
                                    headers.append(f'-H "{sec_scheme_name}: <API_KEY>"')
                                elif sec_scheme['in'] == 'query':
                                    if query_string:
                                        query_string += f'&{sec_scheme_name}=<API_KEY>'
                                    else:
                                        query_string = f'{sec_scheme_name}=<API_KEY>'
                                        full_path += f'?{query_string}'
                            elif sec_scheme['type'] == 'http' and sec_scheme.get('scheme') == 'bearer':
                                headers.append('-H "Authorization: Bearer <token>"')
                # Start building the cURL command
                command = f"curl -X {method.upper()} '{api_url}{full_path}'"
                if headers:
                    command += ' \\\n' + ' \\\n'.join(headers)
                # Handle request body
                if 'requestBody' in details:
                    content = details['requestBody']['content']
                    for content_type, media_type in content.items():
                        schema = media_type['schema']
                        body = construct_json_body(schema)
                        if content_type == 'application/json':
                            json_data = json.dumps(body, indent=4)
                            cmd = command + ' \\\n'
                            cmd += f'-H "Content-Type: {content_type}"' + ' \\\n'
                            cmd += f"-d '{json_data}'"
                        elif content_type == 'multipart/form-data':
                            form_fields = []
                            for key, value in body.items():
                                if isinstance(value, list):
                                    # Handle arrays in form data
                                    for item in value:
                                        if isinstance(item, str) and item == '<value>':
                                            form_fields.append(f'-F "{key}=<value>"')
                                        elif isinstance(item, str) and item == '<file>':
                                            form_fields.append(f'-F "{key}=@/path/to/file"')
                                elif isinstance(value, dict):
                                    # Nested objects in form data (rare in multipart)
                                    pass  # Complex handling needed
                                elif value == '<file>':
                                    form_fields.append(f'-F "{key}=@/path/to/file"')
                                elif value == '<value>':
                                    form_fields.append(f'-F "{key}=<value>"')
                                else:
                                    # Use the actual value, including defaults
                                    form_fields.append(f'-F "{key}={value}"')
                            cmd = command + ' \\\n'
                            cmd += ' \\\n'.join(form_fields)
                        else:
                            # You can add support for other content types here
                            continue  # Unsupported content type
                        curl_commands.append(cmd)
                else:
                    curl_commands.append(command)
    return curl_commands



from dataclasses import dataclass
from typing import Literal, NamedTuple

class _FluminaRoute(NamedTuple):
    method: Literal["websocket", "get", "put", "post", "delete"]
    path: str

def gen_wrapper(method, path):
    def wrapper(fn):
        fn._flumina_route = _FluminaRoute(method, path)
        return fn

    return wrapper

def websocket(path: str):
    return gen_wrapper("websocket", path)

def get(path: str):
    return gen_wrapper("get", path)

def put(path: str):
    return gen_wrapper("put", path)

def post(path: str):
    return gen_wrapper("post", path)

def delete(path: str):
    return gen_wrapper("delete", path)




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/audit_log.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/audit_log.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import status_pb2 as gateway_dot_status__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17gateway/audit_log.proto\x12\x07gateway\x1a\x14gateway/status.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xdb\x01\n\rAuditLogEntry\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06method\x18\x02 \x01(\t\x12\x11\n\tprincipal\x18\x03 \x01(\t\x12(\n\x07payload\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x1f\n\x06status\x18\x05 \x01(\x0b\x32\x0f.gateway.Status\x12-\n\ttimestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07message\x18\x07 \x01(\t\x12\x10\n\x08resource\x18\x08 \x01(\t\"\x86\x02\n\x14ListAuditLogsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x34\n\nstart_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x01\x12\x32\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x01\x12\r\n\x05\x65mail\x18\x08 \x01(\t\x12\x17\n\tpage_size\x18\x04 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x06 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x07 \x01(\tB\x04\xe2\x41\x01\x01\"p\n\x15ListAuditLogsResponse\x12*\n\naudit_logs\x18\x01 \x03(\x0b\x32\x16.gateway.AuditLogEntry\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.audit_log_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_LISTAUDITLOGSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTAUDITLOGSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTAUDITLOGSREQUEST'].fields_by_name['start_time']._loaded_options = None
  _globals['_LISTAUDITLOGSREQUEST'].fields_by_name['start_time']._serialized_options = b'\342A\001\001'
  _globals['_LISTAUDITLOGSREQUEST'].fields_by_name['end_time']._loaded_options = None
  _globals['_LISTAUDITLOGSREQUEST'].fields_by_name['end_time']._serialized_options = b'\342A\001\001'
  _globals['_LISTAUDITLOGSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTAUDITLOGSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTAUDITLOGSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTAUDITLOGSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTAUDITLOGSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTAUDITLOGSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTAUDITLOGSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTAUDITLOGSREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_AUDITLOGENTRY']._serialized_start=155
  _globals['_AUDITLOGENTRY']._serialized_end=374
  _globals['_LISTAUDITLOGSREQUEST']._serialized_start=377
  _globals['_LISTAUDITLOGSREQUEST']._serialized_end=639
  _globals['_LISTAUDITLOGSRESPONSE']._serialized_start=641
  _globals['_LISTAUDITLOGSRESPONSE']._serialized_end=753
# @@protoc_insertion_point(module_scope)



from . import options_pb2 as _options_pb2
from . import status_pb2 as _status_pb2
from ..google.api import field_behavior_pb2 as _field_behavior_pb2
from ..google.api import resource_pb2 as _resource_pb2
from ..google.api import visibility_pb2 as _visibility_pb2
from google.protobuf import field_mask_pb2 as _field_mask_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class User(_message.Message):
    __slots__ = ("name", "display_name", "first_name", "last_name", "stated_role", "create_time", "role", "email", "state", "status", "update_time")
    class State(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        STATE_UNSPECIFIED: _ClassVar[User.State]
        CREATING: _ClassVar[User.State]
        READY: _ClassVar[User.State]
        UPDATING: _ClassVar[User.State]
        DELETING: _ClassVar[User.State]
    STATE_UNSPECIFIED: User.State
    CREATING: User.State
    READY: User.State
    UPDATING: User.State
    DELETING: User.State
    NAME_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    FIRST_NAME_FIELD_NUMBER: _ClassVar[int]
    LAST_NAME_FIELD_NUMBER: _ClassVar[int]
    STATED_ROLE_FIELD_NUMBER: _ClassVar[int]
    CREATE_TIME_FIELD_NUMBER: _ClassVar[int]
    ROLE_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    UPDATE_TIME_FIELD_NUMBER: _ClassVar[int]
    name: str
    display_name: str
    first_name: str
    last_name: str
    stated_role: str
    create_time: _timestamp_pb2.Timestamp
    role: str
    email: str
    state: User.State
    status: _status_pb2.Status
    update_time: _timestamp_pb2.Timestamp
    def __init__(self, name: _Optional[str] = ..., display_name: _Optional[str] = ..., first_name: _Optional[str] = ..., last_name: _Optional[str] = ..., stated_role: _Optional[str] = ..., create_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., role: _Optional[str] = ..., email: _Optional[str] = ..., state: _Optional[_Union[User.State, str]] = ..., status: _Optional[_Union[_status_pb2.Status, _Mapping]] = ..., update_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class CreateUserRequest(_message.Message):
    __slots__ = ("parent", "user", "user_id")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    USER_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    parent: str
    user: User
    user_id: str
    def __init__(self, parent: _Optional[str] = ..., user: _Optional[_Union[User, _Mapping]] = ..., user_id: _Optional[str] = ...) -> None: ...

class GetUserRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class ListUsersRequest(_message.Message):
    __slots__ = ("parent", "page_size", "page_token", "filter", "order_by")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    ORDER_BY_FIELD_NUMBER: _ClassVar[int]
    parent: str
    page_size: int
    page_token: str
    filter: str
    order_by: str
    def __init__(self, parent: _Optional[str] = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ..., filter: _Optional[str] = ..., order_by: _Optional[str] = ...) -> None: ...

class ListUsersResponse(_message.Message):
    __slots__ = ("users", "next_page_token", "total_size")
    USERS_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOTAL_SIZE_FIELD_NUMBER: _ClassVar[int]
    users: _containers.RepeatedCompositeFieldContainer[User]
    next_page_token: str
    total_size: int
    def __init__(self, users: _Optional[_Iterable[_Union[User, _Mapping]]] = ..., next_page_token: _Optional[str] = ..., total_size: _Optional[int] = ...) -> None: ...

class UpdateUserRequest(_message.Message):
    __slots__ = ("user", "update_mask")
    USER_FIELD_NUMBER: _ClassVar[int]
    UPDATE_MASK_FIELD_NUMBER: _ClassVar[int]
    user: User
    update_mask: _field_mask_pb2.FieldMask
    def __init__(self, user: _Optional[_Union[User, _Mapping]] = ..., update_mask: _Optional[_Union[_field_mask_pb2.FieldMask, _Mapping]] = ...) -> None: ...

class DeleteUserRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...



from google.protobuf import descriptor_pb2 as _descriptor_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor
RESOURCE_REFERENCE_FIELD_NUMBER: _ClassVar[int]
resource_reference: _descriptor.FieldDescriptor
RESOURCE_DEFINITION_FIELD_NUMBER: _ClassVar[int]
resource_definition: _descriptor.FieldDescriptor
RESOURCE_FIELD_NUMBER: _ClassVar[int]
resource: _descriptor.FieldDescriptor

class ResourceDescriptor(_message.Message):
    __slots__ = ("type", "pattern", "name_field", "history", "plural", "singular", "style")
    class History(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        HISTORY_UNSPECIFIED: _ClassVar[ResourceDescriptor.History]
        ORIGINALLY_SINGLE_PATTERN: _ClassVar[ResourceDescriptor.History]
        FUTURE_MULTI_PATTERN: _ClassVar[ResourceDescriptor.History]
    HISTORY_UNSPECIFIED: ResourceDescriptor.History
    ORIGINALLY_SINGLE_PATTERN: ResourceDescriptor.History
    FUTURE_MULTI_PATTERN: ResourceDescriptor.History
    class Style(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        STYLE_UNSPECIFIED: _ClassVar[ResourceDescriptor.Style]
        DECLARATIVE_FRIENDLY: _ClassVar[ResourceDescriptor.Style]
    STYLE_UNSPECIFIED: ResourceDescriptor.Style
    DECLARATIVE_FRIENDLY: ResourceDescriptor.Style
    TYPE_FIELD_NUMBER: _ClassVar[int]
    PATTERN_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_FIELD_NUMBER: _ClassVar[int]
    HISTORY_FIELD_NUMBER: _ClassVar[int]
    PLURAL_FIELD_NUMBER: _ClassVar[int]
    SINGULAR_FIELD_NUMBER: _ClassVar[int]
    STYLE_FIELD_NUMBER: _ClassVar[int]
    type: str
    pattern: _containers.RepeatedScalarFieldContainer[str]
    name_field: str
    history: ResourceDescriptor.History
    plural: str
    singular: str
    style: _containers.RepeatedScalarFieldContainer[ResourceDescriptor.Style]
    def __init__(self, type: _Optional[str] = ..., pattern: _Optional[_Iterable[str]] = ..., name_field: _Optional[str] = ..., history: _Optional[_Union[ResourceDescriptor.History, str]] = ..., plural: _Optional[str] = ..., singular: _Optional[str] = ..., style: _Optional[_Iterable[_Union[ResourceDescriptor.Style, str]]] = ...) -> None: ...

class ResourceReference(_message.Message):
    __slots__ = ("type", "child_type")
    TYPE_FIELD_NUMBER: _ClassVar[int]
    CHILD_TYPE_FIELD_NUMBER: _ClassVar[int]
    type: str
    child_type: str
    def __init__(self, type: _Optional[str] = ..., child_type: _Optional[str] = ...) -> None: ...



from abc import abstractmethod
import os
import torch
from contextlib import contextmanager
from dataclasses import dataclass
import enum
from typing import Dict, Optional


class FluminaModule(torch.nn.Module):
    # Addon interface
    @abstractmethod
    def load_addon(
        self,
        addon_account_id: str,
        addon_model_id: str,
        addon_type: str,
        addon_data_path: os.PathLike,
    ): ...

    @abstractmethod
    def unload_addon(
        self,
        addon_account_id: str,
        addon_model_id: str,
        addon_type: str,
    ): ...

    @abstractmethod
    def activate_addon(
        self,
        addon_account_id: str,
        addon_model_id: str,
    ): ...

    @abstractmethod
    def deactivate_addon(
        self,
        addon_account_id: str,
        addon_model_id: str,
    ): ...


@dataclass
class _MaterializedModule:
    module: FluminaModule
    path_to_method_name: Dict[str, str]


class _ExecMode(enum.Enum):
    NONE = 0
    VALIDATE = 1
    SERVE = 2


_exec_mode = _ExecMode.NONE
_materialized_module: Optional[_MaterializedModule] = None


def _get_materialized_module():
    global _materialized_module
    em = _materialized_module
    _materialized_module = None
    return em


@contextmanager
def _with_exec_mode(mode):
    global _exec_mode
    old_mode = _exec_mode
    _exec_mode = mode
    try:
        yield
    finally:
        _exec_mode = old_mode


def main(m: FluminaModule):
    if _exec_mode == _ExecMode.NONE:
        pass
    elif _exec_mode in {_ExecMode.VALIDATE, _ExecMode.SERVE}:
        assert isinstance(
            m, FluminaModule
        ), "Argument to flumina.main() must be an instance of FluminaModule"
        path_to_method_name: Dict[str, str] = {}
        for k in dir(m):
            v = getattr(m, k)
            if hasattr(v, "_flumina_route"):
                path_to_method_name[v._flumina_route] = k

        global _materialized_module
        _materialized_module = _MaterializedModule(
            module=m,
            path_to_method_name=path_to_method_name,
        )
    else:
        raise NotImplementedError("Unsupported ExecMode", _exec_mode)



from google.protobuf import descriptor_pb2 as _descriptor_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor
API_RESOURCE_FIELD_NUMBER: _ClassVar[int]
api_resource: _descriptor.FieldDescriptor
API_ONLY_FIELD_NUMBER: _ClassVar[int]
api_only: _descriptor.FieldDescriptor
GORM_JSON_FIELD_NUMBER: _ClassVar[int]
gorm_json: _descriptor.FieldDescriptor
SHOW_IF_ZERO_FIELD_NUMBER: _ClassVar[int]
show_if_zero: _descriptor.FieldDescriptor
GORM_INDEX_FIELD_NUMBER: _ClassVar[int]
gorm_index: _descriptor.FieldDescriptor
GORM_UNIQUE_INDEX_FIELD_NUMBER: _ClassVar[int]
gorm_unique_index: _descriptor.FieldDescriptor
GORM_UNIQUE_NAMED_INDEX_FIELD_NUMBER: _ClassVar[int]
gorm_unique_named_index: _descriptor.FieldDescriptor

class ApiResource(_message.Message):
    __slots__ = ("parent_type", "skip_gorm", "has_db_only_fields")
    PARENT_TYPE_FIELD_NUMBER: _ClassVar[int]
    SKIP_GORM_FIELD_NUMBER: _ClassVar[int]
    HAS_DB_ONLY_FIELDS_FIELD_NUMBER: _ClassVar[int]
    parent_type: str
    skip_gorm: bool
    has_db_only_fields: bool
    def __init__(self, parent_type: _Optional[str] = ..., skip_gorm: bool = ..., has_db_only_fields: bool = ...) -> None: ...



from ..buf.validate import validate_pb2 as _validate_pb2
from . import deployment_pb2 as _deployment_pb2
from . import options_pb2 as _options_pb2
from . import status_pb2 as _status_pb2
from . import training_pb2 as _training_pb2
from . import wandb_pb2 as _wandb_pb2
from ..google.api import field_behavior_pb2 as _field_behavior_pb2
from ..google.api import resource_pb2 as _resource_pb2
from ..google.api import visibility_pb2 as _visibility_pb2
from google.protobuf import field_mask_pb2 as _field_mask_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class EagleTrainingJob(_message.Message):
    __slots__ = ("name", "display_name", "create_time", "expire_time", "created_by", "state", "status", "input_draft_model", "training_dataset", "base_model", "output_draft_model", "epochs_count", "learning_rate", "wandb_config", "early_stop_config", "accelerator_type", "accelerator_count", "update_time")
    NAME_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    CREATE_TIME_FIELD_NUMBER: _ClassVar[int]
    EXPIRE_TIME_FIELD_NUMBER: _ClassVar[int]
    CREATED_BY_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    INPUT_DRAFT_MODEL_FIELD_NUMBER: _ClassVar[int]
    TRAINING_DATASET_FIELD_NUMBER: _ClassVar[int]
    BASE_MODEL_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_DRAFT_MODEL_FIELD_NUMBER: _ClassVar[int]
    EPOCHS_COUNT_FIELD_NUMBER: _ClassVar[int]
    LEARNING_RATE_FIELD_NUMBER: _ClassVar[int]
    WANDB_CONFIG_FIELD_NUMBER: _ClassVar[int]
    EARLY_STOP_CONFIG_FIELD_NUMBER: _ClassVar[int]
    ACCELERATOR_TYPE_FIELD_NUMBER: _ClassVar[int]
    ACCELERATOR_COUNT_FIELD_NUMBER: _ClassVar[int]
    UPDATE_TIME_FIELD_NUMBER: _ClassVar[int]
    name: str
    display_name: str
    create_time: _timestamp_pb2.Timestamp
    expire_time: _timestamp_pb2.Timestamp
    created_by: str
    state: _status_pb2.JobState
    status: _status_pb2.Status
    input_draft_model: str
    training_dataset: str
    base_model: str
    output_draft_model: str
    epochs_count: float
    learning_rate: float
    wandb_config: _wandb_pb2.WandbConfig
    early_stop_config: _training_pb2.EarlyStopConfig
    accelerator_type: _deployment_pb2.AcceleratorType
    accelerator_count: int
    update_time: _timestamp_pb2.Timestamp
    def __init__(self, name: _Optional[str] = ..., display_name: _Optional[str] = ..., create_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., expire_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., created_by: _Optional[str] = ..., state: _Optional[_Union[_status_pb2.JobState, str]] = ..., status: _Optional[_Union[_status_pb2.Status, _Mapping]] = ..., input_draft_model: _Optional[str] = ..., training_dataset: _Optional[str] = ..., base_model: _Optional[str] = ..., output_draft_model: _Optional[str] = ..., epochs_count: _Optional[float] = ..., learning_rate: _Optional[float] = ..., wandb_config: _Optional[_Union[_wandb_pb2.WandbConfig, _Mapping]] = ..., early_stop_config: _Optional[_Union[_training_pb2.EarlyStopConfig, _Mapping]] = ..., accelerator_type: _Optional[_Union[_deployment_pb2.AcceleratorType, str]] = ..., accelerator_count: _Optional[int] = ..., update_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class GetEagleTrainingJobRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class CreateEagleTrainingJobRequest(_message.Message):
    __slots__ = ("parent", "eagle_training_job", "eagle_training_job_id")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    EAGLE_TRAINING_JOB_FIELD_NUMBER: _ClassVar[int]
    EAGLE_TRAINING_JOB_ID_FIELD_NUMBER: _ClassVar[int]
    parent: str
    eagle_training_job: EagleTrainingJob
    eagle_training_job_id: str
    def __init__(self, parent: _Optional[str] = ..., eagle_training_job: _Optional[_Union[EagleTrainingJob, _Mapping]] = ..., eagle_training_job_id: _Optional[str] = ...) -> None: ...

class ListEagleTrainingJobsRequest(_message.Message):
    __slots__ = ("parent", "page_size", "page_token", "filter", "order_by")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    ORDER_BY_FIELD_NUMBER: _ClassVar[int]
    parent: str
    page_size: int
    page_token: str
    filter: str
    order_by: str
    def __init__(self, parent: _Optional[str] = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ..., filter: _Optional[str] = ..., order_by: _Optional[str] = ...) -> None: ...

class ListEagleTrainingJobsResponse(_message.Message):
    __slots__ = ("eagle_training_jobs", "next_page_token", "total_size")
    EAGLE_TRAINING_JOBS_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOTAL_SIZE_FIELD_NUMBER: _ClassVar[int]
    eagle_training_jobs: _containers.RepeatedCompositeFieldContainer[EagleTrainingJob]
    next_page_token: str
    total_size: int
    def __init__(self, eagle_training_jobs: _Optional[_Iterable[_Union[EagleTrainingJob, _Mapping]]] = ..., next_page_token: _Optional[str] = ..., total_size: _Optional[int] = ...) -> None: ...

class UpdateEagleTrainingJobRequest(_message.Message):
    __slots__ = ("eagle_training_job", "update_mask")
    EAGLE_TRAINING_JOB_FIELD_NUMBER: _ClassVar[int]
    UPDATE_MASK_FIELD_NUMBER: _ClassVar[int]
    eagle_training_job: EagleTrainingJob
    update_mask: _field_mask_pb2.FieldMask
    def __init__(self, eagle_training_job: _Optional[_Union[EagleTrainingJob, _Mapping]] = ..., update_mask: _Optional[_Union[_field_mask_pb2.FieldMask, _Mapping]] = ...) -> None: ...

class DeleteEagleTrainingJobRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/dataset.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/dataset.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as gateway_dot_options__pb2
from . import status_pb2 as gateway_dot_status__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from ..google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15gateway/dataset.proto\x12\x07gateway\x1a\x15gateway/options.proto\x1a\x14gateway/status.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/api/visibility.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xab\x08\n\x07\x44\x61taset\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x1a\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\x12\x36\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12,\n\x05state\x18\x04 \x01(\x0e\x32\x16.gateway.Dataset.StateB\x05\xe2\x41\x02\x03\x05\x12&\n\x06status\x18\x06 \x01(\x0b\x32\x0f.gateway.StatusB\x05\xe2\x41\x02\x03\x05\x12\x1b\n\rexample_count\x18\x07 \x01(\x03\x42\x04\xe2\x41\x01\x01\x12P\n\raccess_policy\x18\t \x01(\x0e\x32\x1d.gateway.Dataset.AccessPolicyB\x1a\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12.\n\ruser_uploaded\x18\x0b \x01(\x0b\x32\x15.gateway.UserUploadedH\x00\x12\x36\n\x11\x65valuation_result\x18\x0f \x01(\x0b\x32\x19.gateway.EvaluationResultH\x00\x12L\n\x10\x66ireworks_traced\x18\x0c \x01(\x0b\x32\x18.gateway.FireworksTracedB\x16\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLYH\x00\x12O\n\x12\x64raft_model_states\x18\r \x01(\x0b\x32\x19.gateway.DraftModelStatesB\x16\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLYH\x00\x12+\n\x0btransformed\x18\x12 \x01(\x0b\x32\x14.gateway.TransformedH\x00\x12\x1a\n\x0c\x65xternal_url\x18\x10 \x01(\tB\x04\xe2\x41\x01\x01\x12.\n\x06\x66ormat\x18\n \x01(\x0e\x32\x17.gateway.Dataset.FormatB\x05\xe2\x41\x02\x01\x05\x12\x19\n\ncreated_by\x18\x0e \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x35\n\x0bupdate_time\x18\x11 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\"8\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\r\n\tUPLOADING\x10\x01\x12\t\n\x05READY\x10\x02\"\'\n\x0c\x41\x63\x63\x65ssPolicy\x12\x0b\n\x07PRIVATE\x10\x00\x12\n\n\x06PUBLIC\x10\x01\"B\n\x06\x46ormat\x12\x16\n\x12\x46ORMAT_UNSPECIFIED\x10\x00\x12\x08\n\x04\x43HAT\x10\x01\x12\x0e\n\nCOMPLETION\x10\x02\x12\x06\n\x02RL\x10\x03:j\xea\x41X\n\x18\x61pi.fireworks.ai/Dataset\x12)accounts/{AccountId}/datasets/{DatasetId}*\x08\x64\x61tasets2\x07\x64\x61taset\x82\xf1\x04\x0b\n\x07\x41\x63\x63ount\x18\x01\x42\r\n\x0b\x64\x61ta_source\"\x8c\x01\n\x15PreviewDatasetRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"j\n\x16PreviewDatasetResponse\x12\"\n\x08\x65xamples\x18\x01 \x03(\x0b\x32\x10.gateway.Example\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x13\n\x0btotal_count\x18\x03 \x01(\x05\"\x1a\n\x07\x45xample\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\"\x0e\n\x0cUserUploaded\"|\n\x0bTransformed\x12\x1f\n\x11source_dataset_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x14\n\x06\x66ilter\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\x12\x36\n\x0foriginal_format\x18\x03 \x01(\x0e\x32\x17.gateway.Dataset.FormatB\x04\xe2\x41\x01\x01\"\xae\x01\n\x0f\x46ireworksTraced\x12\x14\n\x05model\x18\x01 \x01(\tB\x05\xe2\x41\x02\x02\x05\x12\x19\n\nbase_model\x18\x02 \x01(\tB\x05\xe2\x41\x02\x02\x05\x12\x35\n\nstart_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x02\x05\x12\x33\n\x08\x65nd_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x02\x05\"-\n\x10\x44raftModelStates\x12\x19\n\nbase_model\x18\x01 \x01(\tB\x05\xe2\x41\x02\x02\x05\"3\n\x10\x45valuationResult\x12\x1f\n\x11\x65valuation_job_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\'\n\x11GetDatasetRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\xa6\x01\n\x14\x43reateDatasetRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\'\n\x07\x64\x61taset\x18\x02 \x01(\x0b\x32\x10.gateway.DatasetB\x04\xe2\x41\x01\x02\x12\x18\n\ndataset_id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02\x12\x1f\n\x11source_dataset_id\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"v\n\x14UpdateDatasetRequest\x12\'\n\x07\x64\x61taset\x18\x01 \x01(\x0b\x32\x10.gateway.DatasetB\x04\xe2\x41\x01\x02\x12\x35\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01\"\xb4\x01\n\x14UploadDatasetRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12Q\n\x10\x66ilename_to_size\x18\x02 \x03(\x0b\x32\x31.gateway.UploadDatasetRequest.FilenameToSizeEntryB\x04\xe2\x41\x01\x02\x1a\x35\n\x13\x46ilenameToSizeEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\"\xaf\x01\n\x15UploadDatasetResponse\x12Y\n\x17\x66ilename_to_signed_urls\x18\x01 \x03(\x0b\x32\x38.gateway.UploadDatasetResponse.FilenameToSignedUrlsEntry\x1a;\n\x19\x46ilenameToSignedUrlsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xca\x01\n\x1fGetDatasetUploadEndpointRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\\\n\x10\x66ilename_to_size\x18\x02 \x03(\x0b\x32<.gateway.GetDatasetUploadEndpointRequest.FilenameToSizeEntryB\x04\xe2\x41\x01\x02\x1a\x35\n\x13\x46ilenameToSizeEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\"\xc5\x01\n GetDatasetUploadEndpointResponse\x12\x64\n\x17\x66ilename_to_signed_urls\x18\x01 \x03(\x0b\x32\x43.gateway.GetDatasetUploadEndpointResponse.FilenameToSignedUrlsEntry\x1a;\n\x19\x46ilenameToSignedUrlsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"2\n\x1cValidateDatasetUploadRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"7\n!GetDatasetDownloadEndpointRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\xc9\x01\n\"GetDatasetDownloadEndpointResponse\x12\x66\n\x17\x66ilename_to_signed_urls\x18\x01 \x03(\x0b\x32\x45.gateway.GetDatasetDownloadEndpointResponse.FilenameToSignedUrlsEntry\x1a;\n\x19\x46ilenameToSignedUrlsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8c\x01\n\x13ListDatasetsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"g\n\x14ListDatasetsResponse\x12\"\n\x08\x64\x61tasets\x18\x01 \x03(\x0b\x32\x10.gateway.Dataset\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"*\n\x14\x44\x65leteDatasetRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.dataset_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_DATASET'].fields_by_name['name']._loaded_options = None
  _globals['_DATASET'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_DATASET'].fields_by_name['display_name']._loaded_options = None
  _globals['_DATASET'].fields_by_name['display_name']._serialized_options = b'\342A\001\001'
  _globals['_DATASET'].fields_by_name['create_time']._loaded_options = None
  _globals['_DATASET'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_DATASET'].fields_by_name['state']._loaded_options = None
  _globals['_DATASET'].fields_by_name['state']._serialized_options = b'\342A\002\003\005'
  _globals['_DATASET'].fields_by_name['status']._loaded_options = None
  _globals['_DATASET'].fields_by_name['status']._serialized_options = b'\342A\002\003\005'
  _globals['_DATASET'].fields_by_name['example_count']._loaded_options = None
  _globals['_DATASET'].fields_by_name['example_count']._serialized_options = b'\342A\001\001'
  _globals['_DATASET'].fields_by_name['access_policy']._loaded_options = None
  _globals['_DATASET'].fields_by_name['access_policy']._serialized_options = b'\342A\001\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_DATASET'].fields_by_name['fireworks_traced']._loaded_options = None
  _globals['_DATASET'].fields_by_name['fireworks_traced']._serialized_options = b'\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_DATASET'].fields_by_name['draft_model_states']._loaded_options = None
  _globals['_DATASET'].fields_by_name['draft_model_states']._serialized_options = b'\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_DATASET'].fields_by_name['external_url']._loaded_options = None
  _globals['_DATASET'].fields_by_name['external_url']._serialized_options = b'\342A\001\001'
  _globals['_DATASET'].fields_by_name['format']._loaded_options = None
  _globals['_DATASET'].fields_by_name['format']._serialized_options = b'\342A\002\001\005'
  _globals['_DATASET'].fields_by_name['created_by']._loaded_options = None
  _globals['_DATASET'].fields_by_name['created_by']._serialized_options = b'\342A\002\003\005'
  _globals['_DATASET'].fields_by_name['update_time']._loaded_options = None
  _globals['_DATASET'].fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _globals['_DATASET']._loaded_options = None
  _globals['_DATASET']._serialized_options = b'\352AX\n\030api.fireworks.ai/Dataset\022)accounts/{AccountId}/datasets/{DatasetId}*\010datasets2\007dataset\202\361\004\013\n\007Account\030\001'
  _globals['_PREVIEWDATASETREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_PREVIEWDATASETREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_PREVIEWDATASETREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_PREVIEWDATASETREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_PREVIEWDATASETREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_PREVIEWDATASETREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_PREVIEWDATASETREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_PREVIEWDATASETREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_PREVIEWDATASETREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_PREVIEWDATASETREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_TRANSFORMED'].fields_by_name['source_dataset_id']._loaded_options = None
  _globals['_TRANSFORMED'].fields_by_name['source_dataset_id']._serialized_options = b'\342A\001\002'
  _globals['_TRANSFORMED'].fields_by_name['filter']._loaded_options = None
  _globals['_TRANSFORMED'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_TRANSFORMED'].fields_by_name['original_format']._loaded_options = None
  _globals['_TRANSFORMED'].fields_by_name['original_format']._serialized_options = b'\342A\001\001'
  _globals['_FIREWORKSTRACED'].fields_by_name['model']._loaded_options = None
  _globals['_FIREWORKSTRACED'].fields_by_name['model']._serialized_options = b'\342A\002\002\005'
  _globals['_FIREWORKSTRACED'].fields_by_name['base_model']._loaded_options = None
  _globals['_FIREWORKSTRACED'].fields_by_name['base_model']._serialized_options = b'\342A\002\002\005'
  _globals['_FIREWORKSTRACED'].fields_by_name['start_time']._loaded_options = None
  _globals['_FIREWORKSTRACED'].fields_by_name['start_time']._serialized_options = b'\342A\002\002\005'
  _globals['_FIREWORKSTRACED'].fields_by_name['end_time']._loaded_options = None
  _globals['_FIREWORKSTRACED'].fields_by_name['end_time']._serialized_options = b'\342A\002\002\005'
  _globals['_DRAFTMODELSTATES'].fields_by_name['base_model']._loaded_options = None
  _globals['_DRAFTMODELSTATES'].fields_by_name['base_model']._serialized_options = b'\342A\002\002\005'
  _globals['_EVALUATIONRESULT'].fields_by_name['evaluation_job_id']._loaded_options = None
  _globals['_EVALUATIONRESULT'].fields_by_name['evaluation_job_id']._serialized_options = b'\342A\001\002'
  _globals['_GETDATASETREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETDATASETREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_CREATEDATASETREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATEDATASETREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_CREATEDATASETREQUEST'].fields_by_name['dataset']._loaded_options = None
  _globals['_CREATEDATASETREQUEST'].fields_by_name['dataset']._serialized_options = b'\342A\001\002'
  _globals['_CREATEDATASETREQUEST'].fields_by_name['dataset_id']._loaded_options = None
  _globals['_CREATEDATASETREQUEST'].fields_by_name['dataset_id']._serialized_options = b'\342A\001\002'
  _globals['_CREATEDATASETREQUEST'].fields_by_name['source_dataset_id']._loaded_options = None
  _globals['_CREATEDATASETREQUEST'].fields_by_name['source_dataset_id']._serialized_options = b'\342A\001\001'
  _globals['_CREATEDATASETREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_CREATEDATASETREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEDATASETREQUEST'].fields_by_name['dataset']._loaded_options = None
  _globals['_UPDATEDATASETREQUEST'].fields_by_name['dataset']._serialized_options = b'\342A\001\002'
  _globals['_UPDATEDATASETREQUEST'].fields_by_name['update_mask']._loaded_options = None
  _globals['_UPDATEDATASETREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_UPLOADDATASETREQUEST_FILENAMETOSIZEENTRY']._loaded_options = None
  _globals['_UPLOADDATASETREQUEST_FILENAMETOSIZEENTRY']._serialized_options = b'8\001'
  _globals['_UPLOADDATASETREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPLOADDATASETREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_UPLOADDATASETREQUEST'].fields_by_name['filename_to_size']._loaded_options = None
  _globals['_UPLOADDATASETREQUEST'].fields_by_name['filename_to_size']._serialized_options = b'\342A\001\002'
  _globals['_UPLOADDATASETRESPONSE_FILENAMETOSIGNEDURLSENTRY']._loaded_options = None
  _globals['_UPLOADDATASETRESPONSE_FILENAMETOSIGNEDURLSENTRY']._serialized_options = b'8\001'
  _globals['_GETDATASETUPLOADENDPOINTREQUEST_FILENAMETOSIZEENTRY']._loaded_options = None
  _globals['_GETDATASETUPLOADENDPOINTREQUEST_FILENAMETOSIZEENTRY']._serialized_options = b'8\001'
  _globals['_GETDATASETUPLOADENDPOINTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETDATASETUPLOADENDPOINTREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_GETDATASETUPLOADENDPOINTREQUEST'].fields_by_name['filename_to_size']._loaded_options = None
  _globals['_GETDATASETUPLOADENDPOINTREQUEST'].fields_by_name['filename_to_size']._serialized_options = b'\342A\001\002'
  _globals['_GETDATASETUPLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY']._loaded_options = None
  _globals['_GETDATASETUPLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY']._serialized_options = b'8\001'
  _globals['_VALIDATEDATASETUPLOADREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_VALIDATEDATASETUPLOADREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_GETDATASETDOWNLOADENDPOINTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETDATASETDOWNLOADENDPOINTREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_GETDATASETDOWNLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY']._loaded_options = None
  _globals['_GETDATASETDOWNLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY']._serialized_options = b'8\001'
  _globals['_LISTDATASETSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTDATASETSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTDATASETSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTDATASETSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTDATASETSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTDATASETSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTDATASETSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTDATASETSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTDATASETSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTDATASETSREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_DELETEDATASETREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETEDATASETREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_DATASET']._serialized_start=236
  _globals['_DATASET']._serialized_end=1303
  _globals['_DATASET_STATE']._serialized_start=1015
  _globals['_DATASET_STATE']._serialized_end=1071
  _globals['_DATASET_ACCESSPOLICY']._serialized_start=1073
  _globals['_DATASET_ACCESSPOLICY']._serialized_end=1112
  _globals['_DATASET_FORMAT']._serialized_start=1114
  _globals['_DATASET_FORMAT']._serialized_end=1180
  _globals['_PREVIEWDATASETREQUEST']._serialized_start=1306
  _globals['_PREVIEWDATASETREQUEST']._serialized_end=1446
  _globals['_PREVIEWDATASETRESPONSE']._serialized_start=1448
  _globals['_PREVIEWDATASETRESPONSE']._serialized_end=1554
  _globals['_EXAMPLE']._serialized_start=1556
  _globals['_EXAMPLE']._serialized_end=1582
  _globals['_USERUPLOADED']._serialized_start=1584
  _globals['_USERUPLOADED']._serialized_end=1598
  _globals['_TRANSFORMED']._serialized_start=1600
  _globals['_TRANSFORMED']._serialized_end=1724
  _globals['_FIREWORKSTRACED']._serialized_start=1727
  _globals['_FIREWORKSTRACED']._serialized_end=1901
  _globals['_DRAFTMODELSTATES']._serialized_start=1903
  _globals['_DRAFTMODELSTATES']._serialized_end=1948
  _globals['_EVALUATIONRESULT']._serialized_start=1950
  _globals['_EVALUATIONRESULT']._serialized_end=2001
  _globals['_GETDATASETREQUEST']._serialized_start=2003
  _globals['_GETDATASETREQUEST']._serialized_end=2042
  _globals['_CREATEDATASETREQUEST']._serialized_start=2045
  _globals['_CREATEDATASETREQUEST']._serialized_end=2211
  _globals['_UPDATEDATASETREQUEST']._serialized_start=2213
  _globals['_UPDATEDATASETREQUEST']._serialized_end=2331
  _globals['_UPLOADDATASETREQUEST']._serialized_start=2334
  _globals['_UPLOADDATASETREQUEST']._serialized_end=2514
  _globals['_UPLOADDATASETREQUEST_FILENAMETOSIZEENTRY']._serialized_start=2461
  _globals['_UPLOADDATASETREQUEST_FILENAMETOSIZEENTRY']._serialized_end=2514
  _globals['_UPLOADDATASETRESPONSE']._serialized_start=2517
  _globals['_UPLOADDATASETRESPONSE']._serialized_end=2692
  _globals['_UPLOADDATASETRESPONSE_FILENAMETOSIGNEDURLSENTRY']._serialized_start=2633
  _globals['_UPLOADDATASETRESPONSE_FILENAMETOSIGNEDURLSENTRY']._serialized_end=2692
  _globals['_GETDATASETUPLOADENDPOINTREQUEST']._serialized_start=2695
  _globals['_GETDATASETUPLOADENDPOINTREQUEST']._serialized_end=2897
  _globals['_GETDATASETUPLOADENDPOINTREQUEST_FILENAMETOSIZEENTRY']._serialized_start=2461
  _globals['_GETDATASETUPLOADENDPOINTREQUEST_FILENAMETOSIZEENTRY']._serialized_end=2514
  _globals['_GETDATASETUPLOADENDPOINTRESPONSE']._serialized_start=2900
  _globals['_GETDATASETUPLOADENDPOINTRESPONSE']._serialized_end=3097
  _globals['_GETDATASETUPLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY']._serialized_start=2633
  _globals['_GETDATASETUPLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY']._serialized_end=2692
  _globals['_VALIDATEDATASETUPLOADREQUEST']._serialized_start=3099
  _globals['_VALIDATEDATASETUPLOADREQUEST']._serialized_end=3149
  _globals['_GETDATASETDOWNLOADENDPOINTREQUEST']._serialized_start=3151
  _globals['_GETDATASETDOWNLOADENDPOINTREQUEST']._serialized_end=3206
  _globals['_GETDATASETDOWNLOADENDPOINTRESPONSE']._serialized_start=3209
  _globals['_GETDATASETDOWNLOADENDPOINTRESPONSE']._serialized_end=3410
  _globals['_GETDATASETDOWNLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY']._serialized_start=2633
  _globals['_GETDATASETDOWNLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY']._serialized_end=2692
  _globals['_LISTDATASETSREQUEST']._serialized_start=3413
  _globals['_LISTDATASETSREQUEST']._serialized_end=3553
  _globals['_LISTDATASETSRESPONSE']._serialized_start=3555
  _globals['_LISTDATASETSRESPONSE']._serialized_end=3658
  _globals['_DELETEDATASETREQUEST']._serialized_start=3660
  _globals['_DELETEDATASETREQUEST']._serialized_end=3702
# @@protoc_insertion_point(module_scope)
